//--------------------------------------------------------------------------
// Project              : Transferring Data via Ethernet
// Author               : Habibollah Abdollahypoor
// Chip type            : ATmega32
// Program type         : Application
// Clock frequency      : 6.250000 MHz
// Memory model         : Small
// Data Stack size      : 512
//--------------------------------------------------------------------------
#include <mega32a.h>
#include <stdio.h>
#include <string.h>
#include <delay.h>
#include <alcd.h>
#include <i2c.h>
char temp_to_http_buffer[17],pre_to_http_buffer[17]; 
 #include "bmp180.h"
//--------------------------------------
#define ENC28J60_SPI_PORT       PORTB
#define ENC28J60_SPI_DDR        DDRB
#define ENC28J60_SPI_MISO       6
#define ENC28J60_SPI_MOSI       5
#define ENC28J60_SPI_SCK        7
#define ENC28J60_SPI_CS         4
// ethernet buffer size
#define BUFFER_SIZE             1024
#include "ethernet.h"
//--------------------------------------


#define DIPSWITCH               (PIND>>4)

//--------------------------------------
unsigned char   mymac[6] = {0x11,0x22,0x33,0x44,0x55,0x66};     // MAC
unsigned char   myip[4] = {192,168,1,10};                       // IP
unsigned char   time_cs = 0;            // 1/100 second counter
unsigned int    time_s = 0;             // seconds counter
unsigned int    counter1 = 0;           // button 1 clicks
unsigned int    counter2 = 0;           // button 2 clicks
//--------------------------------------
interrupt [TIM1_OVF] void timer1_ovf_isr(void)  // Timer 1 overflow ISR
{

        static bit old_btn1 = 0, old_btn2 = 0;
        if (++time_cs==100)             // one second elapsed
        {
                time_cs = 0;
                time_s ++;   
                #asm("wdr");
        }
        
}
//--------------------------------------
void main(void)
{
        uint8_t str[20]="";     // buffer to
        char t_lcd_buffer_1[10],t_lcd_buffer_2[10];
   // Watchdog Timer Enabled with Prescaler: OSC/512k
      WDTCR=0x0D;

        PORTB=0x03;
        DDRB=0x00;   
        

        PORTD=0xF0;
        DDRD=0x00;   
      
        // Timer 1 interrupts every 10 ms
        TCCR1A=0x02;
        TCCR1B=0x19;
        ICR1H=0xF4;
        ICR1L=0x23;
        // Timer(s) Interrupt(s) initialization
        TIMSK=0x04;
        // Analog Comparator: Off
        ACSR=0x80;                    
        
         
        
        // LCD module initialization
        lcd_init(16);
        /// milad added 
        lcd_clear();
        lcd_putsf("Sajad Shamsi");
        delay_ms(2000);
        #asm("wdr");
        // setting MAC & IP using dip-switch state
        mymac[0] += DIPSWITCH;
        myip[3] += DIPSWITCH;
        // initialize ethernet
        ethernet_init(mymac, myip, 80, 1200);
        // start up display
        lcd_gotoxy(0,0);
        lcd_putsf("      MAC       ");
        lcd_gotoxy(0,1);
        sprintf(str, " %02x%02x-%02x%02x-%02x%02x ",
                mymac[0], mymac[1], mymac[2], mymac[3], mymac[4], mymac[5]);
        lcd_puts(str);
        delay_ms(2000);
        lcd_gotoxy(0,0);
        lcd_putsf("       IP       ");
        lcd_gotoxy(0,1);
        sprintf(str, "%03u.%03u.%03u.%03u",
                myip[0], myip[1], myip[2], myip[3]);
        lcd_puts(str);
        delay_ms(3000);
        lcd_clear();                
        
          i2c_init();
        calibre(); 

       
        // Global enable interrupts
        #asm("sei")  
        #asm("wdr");
      
       
        while (1)
        {
                #asm("wdr");
                
                lcd_gotoxy(0,0); 
                
                lcd_puts(temp_to_http_buffer); 
                delay_ms(1);  
                lcd_gotoxy(0,1);
                lcd_puts(pre_to_http_buffer);
                 
               show_temp();
               show_pre();   
               ethernet_process(); //process ethernet transactions
               delay_ms(200); 
        }
}
//--------------------------------------
unsigned char ethernet_udp(unsigned char* data, unsigned char data_len)
{
        unsigned char str[20];
       // lcd_gotoxy(0,1);
       // lcd_putsf("UDP:            ");
        strncpy(str, data, 11);
       // lcd_gotoxy(4,1);
       // lcd_puts(str);
        // response the request
        sprintf(str, "T=%u,P=%u,%u\n", time_s, counter1, counter2 );
        data_len = concatstr(data, 0, str);
        time_cs = 0;
        time_s = 0;
        return data_len;
}
//--------------------------------------
unsigned int ethernet_tcp(unsigned char* request, unsigned char* response)
{
        unsigned int len;
        unsigned char str[20];
        if (strncmpf(request, "GET /", 5)!=0)
                return 0;
     //   lcd_gotoxy(0,1);
    //    lcd_putsf("TCP:            ");
    //    strncpy(str, request+5, 11);
     //   lcd_gotoxy(4,1);
      //  lcd_puts(str);
        // response the request
        len = concatstrf(response, 0, "HTTP/1.0 200 OK\r\n");
        len = concatstrf(response, len, "Content-Type: text/html\r\n");
        len = concatstrf(response, len, "Pragma: no-cache\r\n\r\n");
        len = concatstrf(response, len,
                "<HTML><TITLE> DAMA AND FESHAR  </TITLE><BODY><CENTER>");
        len = concatstrf(response, len,
                "<P> Sajad Shamsi  </P>\n<HR>");
       // len = concatstrf(response, len,
       //         "<P>Time = <FONT COLOR=#00FF00> ");
       // sprintf(str, "%u", time_s);
       // len = concatstr(response, len, str);
       // len = concatstrf(response, len, "</FONT></P>\n");
        len = concatstrf(response, len,
                "<P> <FONT COLOR=#0000FF> ");
       // sprintf(str, "%u C", 29 );
        //len = concatstr(response, len, str); 
         
        len = concatstr(response, len, temp_to_http_buffer);  
        len = concatstr(response, len, pre_to_http_buffer);
        
        len = concatstrf(response, len, "</FONT></P>\n");
       // len = concatstrf(response, len,
       //         "<P>Counter_2 = <FONT COLOR=#FF0000> ");
       // sprintf(str, "%u", counter2);
       // len = concatstr(response, len, str);
        len = concatstrf(response, len, "</FONT></P>\n");
        len = concatstrf(response, len,
                "<P><A HREF=\".\">refresh</A><P></CENTER><HR>\n");
        time_cs = 0;
        time_s = 0;
        return len;
}
